@@ -88,9 +88,26 @@ class LeCrapaud:
         """
         return ExperimentEngine(id=id, **kwargs)
 
-    def list_experiments(self, limit=1000) -> list["ExperimentEngine"]:
+    def get_last_experiement_by_name(self, name: str, **kwargs) -> "ExperimentEngine":
+        """Retrieve the last experiment by name."""
+        return ExperimentEngine(id=Experiment.get_last_by_name(name).id, **kwargs)
+
+    def get_best_experiment_by_name(
+        self, name: str, metric: str = "both", **kwargs
+    ) -> "ExperimentEngine":
+        """Retrieve the best experiment by score."""
+        return ExperimentEngine(
+            id=Experiment.get_best_by_score(name=name, metric=metric).id, **kwargs
+        )
+
+    def list_experiments(
+        self, name: str = None, limit: int = 1000
+    ) -> list["ExperimentEngine"]:
         """List all experiments in the database."""
-        return [ExperimentEngine(id=exp.id) for exp in Experiment.get_all(limit=limit)]
+        return [
+            ExperimentEngine(id=exp.id)
+            for exp in Experiment.get_all_by_name(name=name, limit=limit)
+        ]
 
 
 class ExperimentEngine:
