@@ -24,7 +24,7 @@ def create_experiment(
     **kwargs,
 ):
     if isinstance(data, str):
-        path = f"{data}/data/full.pkl" if "data" not in data else f"{data}/full.pkl"
+        path = f"{data}/data/full.pkl"
         data = joblib.load(path)
 
     dates = {}
@@ -35,7 +35,7 @@ def create_experiment(
     groups = {}
     if group_column:
         groups["number_of_groups"] = data[group_column].nunique()
-        groups["list_of_groups"] = data[group_column].unique().tolist()
+        groups["list_of_groups"] = data[group_column].unique().tolist().sort()
 
     with get_db() as db:
         all_targets = Target.get_all(db=db)
