@@ -9,22 +9,22 @@ from ftfy import fix_text
 import unicodedata
 import re
 import string
-
+import sys
 from lecrapaud.directories import logger_dir
-from lecrapaud.config import LOGGING_LEVEL, PYTHON_ENV
+from lecrapaud.config import LOGGING_LEVEL, PYTHON_ENV, LECRAPAUD_LOCAL
 
-_LOGGER_ALREADY_CONFIGURED = False
+_LECRAPAUD_LOGGER_ALREADY_CONFIGURED = False
 
 
 def setup_logger():
 
-    global _LOGGER_ALREADY_CONFIGURED
-    if _LOGGER_ALREADY_CONFIGURED:  # ← bail out if done before
+    global _LECRAPAUD_LOGGER_ALREADY_CONFIGURED
+    if _LECRAPAUD_LOGGER_ALREADY_CONFIGURED:  # ← bail out if done before
 
         return logging.getLogger("lecrapaud" if PYTHON_ENV != "Worker" else "")
 
     print(
-        f"Setting up logger with PYTHON_ENV {PYTHON_ENV} and LOGGING_LEVEL {LOGGING_LEVEL}"
+        f"Setting up logger lecrapaud with PYTHON_ENV {PYTHON_ENV} and LOGGING_LEVEL {LOGGING_LEVEL}"
     )
     # ------------------------------------------------------------------ #
     #  Real configuration happens only on the FIRST call                 #
@@ -47,20 +47,24 @@ def setup_logger():
         "Worker": "worker.log",
     }.get(PYTHON_ENV, "app.log")
 
-    file_handler = RotatingFileHandler(
-        f"{logger_dir}/{env_file}",
-        maxBytes=5 * 1024 * 1024,
-        backupCount=3,
-    )
-    file_handler.setFormatter(formatter)
-    file_handler.setLevel(log_level)
-    logger.addHandler(file_handler)
+    if logger_dir:
+        file_handler = RotatingFileHandler(
+            f"{logger_dir}/{env_file}",
+            maxBytes=5 * 1024 * 1024,
+            backupCount=3,
+        )
+        file_handler.setFormatter(formatter)
+        file_handler.setLevel(log_level)
+        logger.addHandler(file_handler)
 
-    _LOGGER_ALREADY_CONFIGURED = True
+    _LECRAPAUD_LOGGER_ALREADY_CONFIGURED = True
     return logger
 
 
-logger = setup_logger()
+if LECRAPAUD_LOCAL:
+    logger = setup_logger()
+else:
+    logger = logging.getLogger(__name__)
 
 
 def get_df_name(obj, namespace):
